==> haskell-network-multicast-0.3.2-312.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-1OEwTX0Qtig3Km2xyPuA4S
key:                  network-multicast-0.3.2-1OEwTX0Qtig3Km2xyPuA4S
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  01a81c1eaf11bda576e5b29d7135aad9
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-1OEwTX0Qtig3Km2xyPuA4S
depends:
    base-4.18.2.1 network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe
    network-bsd-2.8.1.0-tw2oRH0FuUAjhgeHdG5Oa

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.3.2-313-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 network-multicast
version:              0.3.2
visibility:           public
id:                   network-multicast-0.3.2-FNTzEzPo7X6EqC0purp8Qx
key:                  network-multicast-0.3.2-FNTzEzPo7X6EqC0purp8Qx
license:              LicenseRef-PublicDomain
copyright:            2008-2019 Audrey Tang
maintainer:           Marco Zocca
author:               Audrey Tang <audreyt@audreyt.org>
stability:            experimental
synopsis:             Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.

category:             Network
abi:                  79bc046f637f41cabb4424c4b880b650
exposed:              True
exposed-modules:      Network.Multicast
import-dirs:          /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/network-multicast-0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-network-multicast
hs-libraries:         HSnetwork-multicast-0.3.2-FNTzEzPo7X6EqC0purp8Qx
depends:
    base-4.18.2.1 network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ
    network-bsd-2.8.1.0-D7anFlGqSCnK99qTn3SolU

haddock-interfaces:
    /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock

haddock-html:         /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
